@@ -35,6 +35,7 @@ def parse_config(self, filename):
         return options
 
 
+
 class Ui_MainWindow(QWidget):
     def __init__(self):
         QWidget.__init__(self, None)
@@ -288,7 +289,7 @@ class ConfigWindow(QMainWindow):
 	self.comboSampleRate.setGeometry(QRect(530, 170, 250, 60))
 	Sam_Rates = self.listDefaultFirst("samplerate",['8192','11025','22050','32000','44100','48000'])
 	for SampRate in Sam_Rates:
-        		 	self.comboSampleRate.addItem(SampRate)
+		self.comboSampleRate.addItem(SampRate)
 	# Save button
         self.saveButton = QPushButton("SAVE",self)
         self.saveButton.setStyleSheet(
@@ -418,7 +419,6 @@ class keyWindow(QDialog):
 	grid = QGridLayout(wg)
 	wg.show()
 	area.show()
-	grid.setColumnStretch(1, 10)
 	grid.setColumnStretch(2, 20)
         font = QFont()
         font.setPointSize(24)
@@ -430,6 +430,8 @@ class keyWindow(QDialog):
 	self.AkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("A"), 1, 0 )
 	grid.addWidget(self.AkeySpinBox, 1, 1)
+	self.AButton = MyKeyPressed("pick A key",self)
+	grid.addWidget(self.AButton, 1, 2)
 	# B-button
 	self.BkeySpinBox = QDoubleSpinBox()
 	self.BkeySpinBox.setRange(1, 300)
@@ -437,6 +439,8 @@ class keyWindow(QDialog):
 	self.BkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("B"), 2, 0)
 	grid.addWidget(self.BkeySpinBox, 2, 1)
+	self.BButton = MyKeyPressed("pick B key",self)
+	grid.addWidget(self.BButton, 2, 2)
 	# C-button
 	self.CkeySpinBox = QDoubleSpinBox()
 	self.CkeySpinBox.setRange(1, 300)
@@ -444,6 +448,8 @@ class keyWindow(QDialog):
 	self.CkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("C"), 3, 0)
 	grid.addWidget(self.CkeySpinBox, 3, 1)
+	self.CButton = MyKeyPressed("pick C key",self)
+	grid.addWidget(self.CButton, 3, 2)
 	# D-button
 	self.DkeySpinBox = QDoubleSpinBox()
 	self.DkeySpinBox.setRange(0, 300)
@@ -451,6 +457,8 @@ class keyWindow(QDialog):
 	self.DkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("D"), 4, 0)
 	grid.addWidget(self.DkeySpinBox, 4, 1)
+	self.DButton = MyKeyPressed("pick D key",self)
+	grid.addWidget(self.DButton, 4, 2)
 	# Start-button
 	self.StartkeySpinBox = QDoubleSpinBox()
 	self.StartkeySpinBox.setRange(0, 300)
@@ -458,6 +466,8 @@ class keyWindow(QDialog):
 	self.StartkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("START"), 5, 0)
 	grid.addWidget(self.StartkeySpinBox, 5, 1)
+	self.StartButton = MyKeyPressed("pick START key",self)
+	grid.addWidget(self.StartButton, 5, 2)
 	# Coin-button
 	self.CoinkeySpinBox = QDoubleSpinBox()
 	self.CoinkeySpinBox.setRange(0, 300)
@@ -465,6 +475,8 @@ class keyWindow(QDialog):
 	self.CoinkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("COIN"), 6, 0)
 	grid.addWidget(self.CoinkeySpinBox, 6, 1)
+	self.CoinButton = MyKeyPressed("pick COIN key",self)
+	grid.addWidget(self.CoinButton, 6, 2)
 	# Up-key
 	self.UpkeySpinBox = QDoubleSpinBox()
 	self.UpkeySpinBox.setRange(0, 300)
@@ -472,6 +484,8 @@ class keyWindow(QDialog):
 	self.UpkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("UP"), 7, 0)
 	grid.addWidget(self.UpkeySpinBox, 7, 1)
+	self.UpButton = MyKeyPressed("pick UP key",self)
+	grid.addWidget(self.UpButton, 7, 2)
 	# Down-key
 	self.DownkeySpinBox = QDoubleSpinBox()
 	self.DownkeySpinBox.setRange(0, 300)
@@ -479,6 +493,8 @@ class keyWindow(QDialog):
 	self.DownkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("DOWN"), 8, 0)
 	grid.addWidget(self.DownkeySpinBox, 8, 1)
+	self.DownButton = MyKeyPressed("pick DOWN key",self)
+	grid.addWidget(self.DownButton, 8, 2)
 	# Left-key
 	self.LeftkeySpinBox = QDoubleSpinBox()
 	self.LeftkeySpinBox.setRange(0, 300)
@@ -486,6 +502,8 @@ class keyWindow(QDialog):
 	self.LeftkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("LEFT"), 9, 0)
 	grid.addWidget(self.LeftkeySpinBox, 9, 1)
+	self.LeftButton = MyKeyPressed("pick LEFT key",self)
+	grid.addWidget(self.LeftButton, 9, 2)
 	# Right-key
 	self.RightkeySpinBox = QDoubleSpinBox()
 	self.RightkeySpinBox.setRange(0, 300)
@@ -493,6 +511,8 @@ class keyWindow(QDialog):
 	self.RightkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("RIGHT"), 10, 0)
 	grid.addWidget(self.RightkeySpinBox, 10, 1)
+	self.RightButton = MyKeyPressed("pick RIGHT key",self)
+	grid.addWidget(self.RightButton, 10, 2)
 
 	self.setLayout(grid)
 	self.connect(self.AkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
@@ -505,6 +525,46 @@ class keyWindow(QDialog):
 	self.connect(self.DownkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
 	self.connect(self.LeftkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
 	self.connect(self.RightkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.RightButton, SIGNAL("keyPressed"),self.updateRight)
+        self.connect(self.LeftButton, SIGNAL("keyPressed"),self.updateLeft)
+        self.connect(self.DownButton, SIGNAL("keyPressed"),self.updateDown)
+        self.connect(self.UpButton, SIGNAL("keyPressed"),self.updateUp)
+        self.connect(self.CoinButton, SIGNAL("keyPressed"),self.updateCoin)
+        self.connect(self.StartButton, SIGNAL("keyPressed"),self.updateStart)
+        self.connect(self.AButton, SIGNAL("keyPressed"),self.updateA)
+        self.connect(self.BButton, SIGNAL("keyPressed"),self.updateB)
+        self.connect(self.CButton, SIGNAL("keyPressed"),self.updateC)
+        self.connect(self.DButton, SIGNAL("keyPressed"),self.updateD)
+
+    def updateRight(self):
+	self.RightkeySpinBox.setValue(float(AsciiVal))
+		
+    def updateLeft(self):
+	self.LeftkeySpinBox.setValue(float(AsciiVal))
+
+    def updateUp(self):
+	self.UpkeySpinBox.setValue(float(AsciiVal))
+
+    def updateDown(self):
+	self.DownkeySpinBox.setValue(float(AsciiVal))
+
+    def updateStart(self):
+	self.StartkeySpinBox.setValue(float(AsciiVal))
+
+    def updateCoin(self):
+	self.CoinkeySpinBox.setValue(float(AsciiVal))
+
+    def updateA(self):
+	self.AkeySpinBox.setValue(float(AsciiVal))
+
+    def updateB(self):
+	self.BkeySpinBox.setValue(float(AsciiVal))
+
+    def updateC(self):
+	self.CkeySpinBox.setValue(float(AsciiVal))
+
+    def updateD(self):
+	self.DkeySpinBox.setValue(float(AsciiVal))
 
     def change_value(self,event):
 	self.P1Keys[0] = "%.0f" % self.AkeySpinBox.value()
@@ -520,6 +580,51 @@ class keyWindow(QDialog):
 	global buttons
 	buttons = self.P1Keys
 
+
+class MyKeyPressed(QPushButton):
+    def __init__(self, *args):
+        QPushButton.__init__(self, *args)
+
+    def event(self, event):
+        if (event.type()==QEvent.KeyPress):
+            # we have to get the SDL keysym
+            #print event.key()
+	    global AsciiVal
+            if (event.key() < 256):
+                AsciiVal = ord(str.lower(chr(event.key())))
+            if (event.key() == 16777236):
+		# right
+                AsciiVal = 275;
+	    if (event.key() == 16777234):
+                # left
+                AsciiVal = 276;
+            if (event.key() == 16777235):
+                # up
+                AsciiVal = 273;
+            if (event.key() == 16777237):
+                # down
+                AsciiVal = 274;
+            if (event.key() == 16777219):
+                # BS
+                AsciiVal = 8;
+            if (event.key() == 16777221):
+                # Return
+                AsciiVal = 13;
+            if (event.key() == 16777248):
+                # R-Shift
+                AsciiVal = 303;
+            if (event.key() == 16777249):
+                # R-Control
+                AsciiVal = 305;
+            if (event.key() == 16781571):
+                # R-Alt
+                AsciiVal = 307;
+            self.emit(SIGNAL("keyPressed"))
+            #return True
+
+        return QPushButton.event(self, event)
+
+
 class pathWindow(QDialog):
     def __init__(self, parent=None):
         super(pathWindow, self).__init__(parent)
